@@ -1,6 +1,6 @@
 from django.contrib.auth.decorators import user_passes_test
 
-from django_otp import devices_for_user
+from django_otp import devices_for_user, user_has_device
 from django_otp.conf import settings
 
 
@@ -17,18 +17,7 @@ def otp_required(view=None, redirect_field_name='next', login_url=None, if_confi
     if login_url is None:
         login_url = settings.OTP_LOGIN_URL
 
-    if if_configured:
-        def test(user):
-            try:
-                if user.is_authenticated():
-                    next(devices_for_user(user, confirmed=True))
-            except StopIteration:
-                return True  # No devices
-            else:
-                return user.is_verified()
-    else:
-        test = lambda u: u.is_verified()
-
+    test = lambda user: user.is_verified() or (if_configured and user.is_authenticated() and not user_has_device(user))
     decorator = user_passes_test(test, login_url=login_url, redirect_field_name=redirect_field_name)
 
     return decorator if (view is None) else decorator(view)
