@@ -31,6 +31,15 @@ class Device(models.Model):
     Abstract base model for a :term:`device` attached to a user. Plugins must
     subclass this to define their OTP models.
 
+    .. _unsaved_device_warning:
+
+    .. warning::
+
+        OTP devices are inherently stateful. For example, verifying a token is
+        logically a mutating operation on the device, which may involve
+        incrementing a counter or otherwise consuming a token. A device must be
+        committed to the database before it can be used in any way.
+
     .. attribute:: user
 
         *ForeignKey*: Foreign key to your user model, as configured by
@@ -119,14 +128,14 @@ class Device(models.Model):
         :rtype: string or ``None``
 
         :raises: Any :exc:`~exceptions.Exception` is permitted. Callers should
-            trap Exception and report it to the user.
+            trap ``Exception`` and report it to the user.
         """
         return None
     generate_challenge.stub = True
 
     def verify_token(self, token):
         """
-        Verifies a token. In many cases, the token will no longer be valid if
+        Verifies a token. In some cases, the token will no longer be valid if
         this returns ``True``.
 
         :param string token: The OTP token provided by the user.
